if(!dojo._hasResource["com.ibm.UnloadGuard"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.UnloadGuard"] = true;
dojo.provide("com.ibm.UnloadGuard");

(function(){
	
	// This utility is used for guarding against unload events when certain events
	// are still pending.  It provides topics for adding and removing pending events
	// through the dojo.publish/subscribe model.
	
	// If events are still pending when the window tries to unload, a confirmation dialog
	// will be displayed to the user with one of the outstanding pending messages, allowing the user
	// to cancel the unload event and stay on the page if the user so chooses.  There is no
	// way to determine which message amongst the list of pending events is displayed to the user as
	// the only guarantee is that one of them will be displayed.
	
	// Other things can subscribe to these topics also in order to perform other functions.
	// An example could be a widget that shows some visual indicator while certain events are
	// still pending and hides itself when they complete.
	
	// Below is a list of topics used by this module.  The arguments that this utility is interested
	// in are also documented, however, any additional arguments can be used by other modules
	// that are also interested in these topics.  However, this utility will only use the arguments
	// specified below.  Other things can subscribe to these topics also in order to perform other 
	// functions.  An example could be a widget that shows some visual indicator while certain events 
	// are still pending and hides itself when they complete.
	//
	// Topics:
	//		"/window/unload/addPending" - Publish to this with one argument which is the message 
	//			to display to the user if the window is unloaded before the event is completed.
	//		
	//		"/window/unload/removePending" - Publish to this with one argument which is a previously
	//			added message in order to remove this message from the list of pending events.
	//				
	//		"/window/unload/nonePending" - Do not publish to this topic.  It is published to by this
	//			module whenever there are no more pending events after a previous one was removed.
	//			It is meant to be subscribed to.
	
	var pending = {};
	
	var isPending = function() {
		for(var x in pending) {
			if(pending[x] && pending[x].length > 0) return x;
		}
		return false;
	}
	
	var addPending = function(message) {
		if(!pending[message]) pending[message] = [];
		pending[message].push(true);
	}
	
	var removePending = function(message) {
		if(pending[message]) {
			pending[message].pop();
		}
		if(!isPending()) {
			dojo.publish("/window/unload/nonePending");
		}
	}
	

	dojo.subscribe("/window/unload/addPending", null, addPending);
	dojo.subscribe("/window/unload/removePending", null, removePending);

	window.onbeforeunload = function() {
		var msg = isPending();
		if(msg !== false) return msg;
	}
})();

}
