dojo.provide("com.ibm.pb.data.TaggedItemStore");
dojo.require("com.ibm.data.CatalogMixin");
dojo.require("com.ibm.data.OpenSearchFeedStore");
dojo.declare("com.ibm.pb.data.TaggedItemStore", 
	[com.ibm.data.OpenSearchFeedStore,com.ibm.data.CatalogMixin],
	{	
		itemClass: "com.ibm.data.TaggedItem",
		searchable: false,
		noIcons: true,
		prefix: "rm:pdl:oid:",
		roleLevel: null,
		
		namespaces: dojo.mixin({}, com.ibm.data.OpenSearchFeedStore.prototype.namespaces, {
			"model" : "http://www.ibm.com/xmlns/prod/websphere/portal/v6.0.1/portal-model-elements",
			"base" : "http://www.ibm.com/xmlns/prod/websphere/portal/v6.0/ibm-portal-composite-base",
			"thr" : "http://purl.org/syndication/thread/1.0",
			"xhtml" : "http://www.w3.org/1999/xhtml",
			"xsi" : "http://www.w3.org/2001/XMLSchema-instance",
			"portal" : "http://www.ibm.com/xmlns/prod/websphere/portal/v6.0.1/portal-model"
		}),
		
		mapItem: function(/*item*/item){
			// summary: get the id, label and description for the item
			var map = {};
			map.id = this.getEPResolvedValue(item, "id", null);
			if(map.id) { map.id = map.id.substring(this.prefix.length); }  // strips off the "pdl:"
			map.label = this.getEPResolvedValue(item, "title", "untitled");
			map.description = this.getEPResolvedValue(item, "summary", "");
			return map;
		},
			
		prepareQuery: function(keywordArgs) {
			// summary: convert the count and start parameters from keywordArgs to num and start parameters in keywordArgs.query
			if(!keywordArgs.query) { keywordArgs.query = {}; }
			if(keywordArgs.count){
				keywordArgs.query["max-results"] = keywordArgs.count;
				delete keywordArgs.count;
			}
			if(keywordArgs.start >= 0){
				keywordArgs.query["start-index"] = keywordArgs.start;
				delete keywordArgs.start;
			}
			return keywordArgs;
		},
		
		validateSelf: function(){
			if(!this.roleLevel) return true;
			var navModel = com.ibm.mashups.enabler.navigation.Factory.getNavigationModel(),
				pageId = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().getID(),
				page = navModel.find(pageId).start();
			return page.hasRole(this.roleLevel);
		},
			
		getSourceLabel: function(){
			if(!this.category) return false;
			var categories = this._getCategories();
			for (var i = 0; i < categories.length; i++) {
				var category = categories[i];
				var id = category.getID();
				if(id.indexOf(this.category) == 0) return com.ibm.mm.builder.utils.htmlUtil.escapeString(category.getTitle(dojo.locale || ibmConfig["default.locale"]));
			}
			return false;
		},
		
		_getCategories: function(){
			if (this.catalogEntries) { return this.catalogEntries; }
			this.catalogEntries = [];
			var cm = com.ibm.mashups.enabler.model.Factory.getCatalogCategoryModel(),
				rootNode = cm.getRoot().start(),
				iter = cm.getChildren(rootNode);
			while (iter.hasNext()) {
				this.catalogEntries.push(iter.next());
			}
			return this.catalogEntries;
		}
});

dojo.declare("com.ibm.data.TaggedItem",
	com.ibm.data.OpenSearchFeedItem, 
	{
		namespaces: dojo.mixin({}, com.ibm.pb.data.TaggedItemStore.prototype.namespaces)
	}
);
