/* Copyright IBM Corp. 2012  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.model.space.SpaceExtensionResult");

/**
 * SpaceExtensionResult class.
 * @ibm-api
 * @ibm-module SpaceModel
 */
dojo.declare("com.ibm.mashups.enabler.model.space.SpaceExtensionResult", null, {
    STATE_OK: "OK",
    STATE_WARNING: "WARNING",
    STATE_ERROR: "ERROR",

    /**
     * Defining the constructor function of the class.
     * The instance of this class is used to carry the return value of SpaceExtension methods.
     *
     * result: String value, indicate the overall status of result. Must be one of following -
     *                SpaceExtensionResult.STATE_OK
     *                SpaceExtensionResult.STATE_WARNING
     *                SpaceExtensionResult.STATE_ERROR
     *
     * This class may also have following fields
     *     message: String, localized message to show what has happened.
     *     solution: String, localized solution message to suggest what actions can be taken to correct the problem.
     *     optionalInfo: this is a field reserved for future.
     */
    constructor: function(result){
        this.result = result;
    },
    
    /**
     * Returns a String value to indicate the overall state of the SpaceExtensionResult
     */
    getState: function(){
        return this.result;
    },
    
    /**
     * Returns localized message
     * return: String, localized message or empty String if mesage doesn't exist.
     */
    getLocaleMessage: function(){
        return this.message || "";
    },
    
    /**
     * Returns localized solution
     * return: String, localized solution message or empty String if solution doesn't exist.
     */
    getLocaleSolution: function(){
        return this.solution || "";
    },
    
    /**
     * Returns additional information from the result.
     * this is reserved for future.
     */
    getOptionalInfo: function(){
        return this.optionalInfo || "";
    },
    
    /**
     * Sets a localized message to the result.
     * localeMessage: String, localized message to show what has happened.
     */
    setLocaleMessage: function(localeMessage){
        this.message = localeMessage;
    },
    
    /**
     * set a localized solution to the result.
     * localeSolution: String, localized solution message to suggest what actions can be taken to correct the problem.
     */
    setLocaleSolution: function(localeSolution){
        this.solution = localeSolution;
    },
    
    /**
     * set additional information to the result.
     * this is reserved for future.
     */
    setOptionalInfo: function(info){
        if (optionalInfo) {
            this.optionalInfo = info;
        }
    }
});
