/* Copyright IBM Corp. 2012  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.persistence.SpaceModelPersistenceProvider");

dojo.require("com.ibm.mashups.enabler.persistence.ModelPersistenceProvider");

dojo.declare("com.ibm.mashups.enabler.persistence.SpaceModelPersistenceProvider", [com.ibm.mashups.enabler.persistence.ModelPersistenceProvider], {

    /**
     * Returns the specified object(s).<br>
     * @param {com.ibm.mashups.enabler.model.url.ModelUrl} url url that specifies the object(s) to find
     * @param {Object} selection selection criteria
     * @param {Object} callback callback function, which is called with the following arguments: 
     * <tt>function(result, status, parameters)</tt>, where<br>
     * <ul>
     * <li><tt>result</tt> is an array containing the selected objects; may contain zero or more objects</li>
     * <li><tt>status</tt> status code of the operation</li>
     * <li><tt>parameters</tt> are the parameters as passed into <tt>findBySelection</tt></li>
     * </ul> 
     * @param {Object} parameters parameters to pass to the callback function; optional
     * @type void
     * @see com.ibm.mashups.enabler.model.url.ModelUrl
     *
     * @ibm-spi
     */
    find: function(url, callback, parameters){
    },
    
    /**
     * Returns the specified object(s).<br>
     * <tt>selection = {</tt><br>
     * &nbsp;&nbsp;<tt>sections: SECTIONS,</tt><br>
     * &nbsp;&nbsp;<tt>pages: {</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>select: PAGE_SELECTION,</tt><br>
     * &nbsp;&nbsp;<tt>},</tt><br>
     * &nbsp;&nbsp;<tt>spaces: {</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>select: SPACE_SELECTION,</tt><br>
     * &nbsp;&nbsp;<tt>},</tt><br>
     * &nbsp;&nbsp;<tt>widgets: {</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>params: {</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<tt>includeDefaultLocale: "true" | "false"</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>}</tt><br>
     * &nbsp;&nbsp;<tt>}</tt><br>
     * <tt>}</tt><br>
     * <br>
     * where
     * <ul>
     * <li><tt>SECTIONS</tt> is an array containing or one or more of the following keywords: 
     * <ul>
     * <li><tt>"pages"</tt>,</li> 
     * <li><tt>"spaces"</tt>,</li>
     * <li><tt>"widgets"</tt>, or</li>
     * </ul>
     * the keyword <tt>"all"</tt> to include all of the above information.</li>
     * <li><tt>PAGE_SELECTION</tt> is an array with one or more of the following keywords:
     * <ul>
     * <li><tt>"children"</tt>,</li>
     * <li><tt>"trail"</tt>, or</li>
     * <li><tt>"topLevel"</tt></li>
     * </ul>
     * </li> 
     * <li><tt>SPACE_SELECTION</tt> is an array with one or more of the following keywords:
     * <ul>
     * <li><tt>"current"</tt> or</li>
     * <li><tt>"favorite"</tt></li>
     * </ul>
     * </li>
     * <li><tt>includeDefaultLocale</tt> if set to <tt>"true"</tt>, widgets contain titles in the 
     * browser default locale. Otherwise the widgets will not contain titles, but the widgets in the
     * page markup will contain titles in the server fall back locale.
     * <ul>
     * <li><tt>"current"</tt> or</li>
     * <li><tt>"favorite"</tt></li>
     * </ul>
     * </li>
     * </ul>
     * <br>
     * <b>Example</b> (select the children of a page):<br>
     * &nbsp;&nbsp;<tt>findBySelection({sections:["pages"], pages: {select: ["children"]}}, function(result) {</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>dojo.forEach(result, function(o) {</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<tt>console.log("page ID: ", o.getID());</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>})</tt><br>
     * &nbsp;&nbsp;<tt>});</tt>
     * 
     * @param {com.ibm.mashups.enabler.model.url.ModelUrl} url url that specifies the object(s) to find
     * @param {Object} selection selection criteria
     * @param {Object} callback callback function, which is called with the following arguments: 
     * <tt>function(result, status, parameters)</tt>, where<br>
     * <ul>
     * <li><tt>result</tt> is an array containing the selected objects; may contain zero or more objects;</li>
     * <li><tt>status</tt> status code of the operation</li>
     * <li><tt>parameters</tt> are the parameters as passed into <tt>findBySelection</tt></li>
     * </ul> 
     * @param {Object} parameters parameters to pass to the callback function; optional
     * @type void
     * @see com.ibm.mashups.enabler.model.url.ModelUrl
     *
     * @ibm-spi
     */
    findBySelection: function(url, selection, callback, parameters){
    },
    
    /**
     * Creates a navigation object based on a given context.<br>
     * context = {
     *   type: TYPE
     * }<br>
     * <br>
     * where
     * <ul>
     * <li><tt>TYPE</tt> is the type of the navigation object, i.e. one of the following
     * <ul>
     * <li><tt>"page"</tt></li>
     * <li><tt>"label"</tt></li>
     * <li><tt>"url"</tt></li>
     * </ul>
     * </li>
     * </ul>
     * @param {Object} context context defining properties for the object to create
     * @return {Object} new navigation object
     * 
     * @ibm-spi
     */
    create: function(context) {
    }
});
